﻿namespace Physics
{
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Distance
        /// </summary>
        /// <seealso cref="Physics.PhysicalQuantities.IPhysical" />
        public partial class Distance : IPhysical
        {
            #region Filed
            
            /// <summary>
            /// Array containing the names of the thermometric scales
            /// </summary>
            public static readonly string[] NameUnit =
            { "Braccio", "Miglio", "Yarda", "Kilometri",
                "Metri", "Pollici", "Piedi", "Miglio Marino" };    

            /// <summary>
            /// Array containing the units of measurement of the thermometric scales
            /// </summary>
            public static readonly string[] SimbUnit =
             {"fm", "M", "yr", "km", "m", "in", "ft", "NM"};

            /// <summary>
            /// Array containing the lower limits of the thermometric scales
            /// </summary>
            public static readonly double[] AbsValue =
                { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };


            private double _value;
            private string _unitMeasure;
            private string _unitSymbol;

            #endregion

            #region Property  

            // Nome e simbolo della grandezza fisica            
            /// <summary>
            /// Gets the name of the measurement.
            /// </summary>
            /// <value>
            /// The name of the measurement.
            /// </value>
            public string MeasurementName { get => "Distanza";}
            /// <summary>
            /// Gets the measurement symbol.
            /// </summary>
            /// <value>
            /// The measurement symbol.
            /// </value>
            public string MeasurementSymbol { get => "D"; }

            // valore scalare, Nome e Simbolo del misurazione da convertire
            /// <summary>
            /// 
            /// </summary>
            public double Unit_Value  { get => _value;       private set => _value       = value; }
            /// <summary>
            /// 
            /// </summary>
            public string Unit_Name   { get => _unitMeasure; private set => _unitMeasure = value; }
            /// <summary>
            /// 
            /// </summary>
            public string Unit_Symbol { get => _unitSymbol;  private set => _unitSymbol  = value; }

            // Matrici contenenti rispettivamente, Nomi, Simboli e Valori limite delle unita' di misura            
            /// <summary>
            /// Gets the name of the unit.
            /// </summary>
            /// <value>
            /// The name of the unit.
            /// </value>
            public string[] UnitName     { get => NameUnit; }
            /// <summary>
            /// Gets the unit symbol.
            /// </summary>
            /// <value>
            /// The unit symbol.
            /// </value>
            public string[] UnitSymbol   { get => SimbUnit; }
            /// <summary>
            /// Gets the unit abs value.
            /// </summary>
            /// <value>
            /// The unit abs value.
            /// </value>
            public double[] UnitAbsValue { get => AbsValue; }

            #endregion
        }
    }
}