﻿using System;

namespace Physics
{
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Distance
        /// </summary>
        public partial class Distance : IPhysical
        {
            /// <summary>
            /// Initializes a new instance with value \"value\" 
            /// and \"symb\" as a thermometric scale
            /// </summary>
            /// <param name="simb">Symbol of unity</param>
            /// <param name="valueTemp">Distance value</param>
            public Distance(string simb, double valueTemp)
            {
                if (CheckUnitName(simb))
                {
                    if (ValidateValue(simb, valueTemp))
                    {
                        _value = valueTemp;
                        _unitSymbol = simb;
                    }
                    else
                    {
                        _unitSymbol = SimbUnit[2];
                        _value = UnitAbsValue[Array.IndexOf(UnitSymbol, simb)];
                    }
                }
                else
                {
                    _unitSymbol = SimbUnit[2];
                    _value = AbsValue[2];
                }
            }

            /// <summary>
            /// Initializes a new instance whit value and symbol of base
            /// </summary>
            public Distance() : this(SimbUnit[0], AbsValue[0])
            {
            }

            /// <summary>
            /// Initializes a new instance of object whit symbol \"simb\" 
            /// and as its value the relative Absolute value
            /// </summary>
            /// <param name="simb">Thermometric Scale Symbol</param>
            public Distance(string simb) : this(simb, 1)
            {
            }

            /// <summary>
            /// Initializes a new instance with value \"value\" 
            /// and with \"k\" (kelvin) as a Thermometric Scale
            /// </summary>
            /// <param name="value">Distance value</param>
            public Distance(double value) : this(SimbUnit[2], value)
            {
            }
        }
    }
}