﻿namespace Physics
{
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Distance
        /// </summary>
        /// <seealso cref="Physics.PhysicalQuantities.IPhysical" />
        public partial class Distance : IPhysical
        {   
            /// <summary>
            /// Converts the value of meters to \"unitSimbol\"
            /// </summary>
            /// <returns>value in degrees \"unitSimbol\"</returns>
            public double ValueToUnit(string unitSimbol)
            {
                switch (unitSimbol)
                {
                    //TODO: Verificare che l'oggetto sia meters e no altro
                    case "m":
                        return  _value * 1000.0;
                    case "Km":
                        return  _value ;
                    case "fm":
                        return  _value* 546.80665;
                    case "yr":
                        return  _value * 1093.61;
                    case "in":
                        return _value * 39370.1;
                    case "ft":
                        return  _value* 3280.841666667;
                     case "M":
                        return  _value * 0.621371;             
                    case "NM":
                        return  _value * 0.54;
                    default:
                        return  _value;
                }
            }

            /// <summary>
            /// Converts the value of \"unitSimbol\" to meters
            /// </summary>
            /// <returns>value of degree meters</returns>
            public double ValueFromUnit()
            {
                switch (_unitSymbol)
                {
                    case "m":
                        return (_value);
                    case "Km":
                        return (_value / 1000.0);
                    case "fm":
                        return (_value / 546.80665);
                    case "yr":
                        return (_value / 1093.61);
                    case "in":
                        return (_value / 39370.1);
                    case "ft":
                        return (_value / 3280.841666667);
                    case "M":
                        return (_value / 0.621371);
                    case "NM":
                        return (_value / 0.54);
                    default:
                        return (UnitAbsValue[0]);
                }
            }

            /// <summary>
            /// Converts the value of meters to \"unitSimbol\"
            /// </summary>
            /// <returns>New Instance in \"UnitSimbol\" degrees</returns>
            public object ObjectToUnit(string UnitSimbol)
            {
                return new Distance(UnitSimbol, ValueToUnit(UnitSimbol));
            }

            /// <summary>
            /// Converts the value of \"unitSimbol\" to meters
            /// </summary>
            /// <returns>New Instance in meters degrees</returns>
            public object ObjectFromUnit()
            {
                return new Distance(ValueFromUnit());
            }

            /// <summary>
            /// Converts a Distance object to the chosen thermometric scale
            /// </summary>
            /// <param name="UnitSimbOut">Output thermometer scale symbol</param>
            /// <returns>New instance of Distance</returns>
            public object ObjectUnitToUnit(string UnitSimbOut)
            {
                // Prima Conversione
                // Converte il valore dell'oggetto in gradi meters
                IPhysical Temporaneo = (IPhysical)ObjectFromUnit();

                return Temporaneo.ObjectToUnit(UnitSimbOut);
            }
            /// <summary>
            /// Values the unit to unit.
            /// </summary>
            /// <param name="UnitSimbOut">The unit simb out.</param>
            /// <returns></returns>
            public double ValueUnitToUnit(string UnitSimbOut)
            {
                // Creo una 2° instanza per evitare modicfiche alla 1°
                Distance temp = new Distance(ValueFromUnit());
                temp.Unit_Value  = temp.ValueToUnit(UnitSimbOut) ;
                temp.Unit_Symbol = UnitSimbOut;
              
                return temp.Unit_Value;
            }
            /// <summary>
            /// Redefines the object.
            /// </summary>
            /// <param name="symbol">Symbol of the new unit</param>
            /// <param name="value">value of the new unit</param>
            public void RedefineObject(string symbol,double value)
            {
                if (CheckUnitName(symbol) && ValidateValue(symbol, value))
                {
                    _value = value;
                    _unitSymbol = symbol;
                }
            }
        }
    }
}