﻿/// <summary>
/// Library for the management of Measurement Physical Quantities
/// </summary>
namespace Physics
{
    /// <summary>
    /// Namespace that contains the physical quantities in the library
    /// </summary>
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Energy
        /// </summary>
        /// <seealso cref="Physics.PhysicalQuantities.IPhysical" />
        public partial class Energy : IPhysical
        {
            #region Filed
            
            /// <summary>
            /// Array containing the names of the thermometric scales
            /// </summary>
            public static readonly string[] NameUnit =
             {"Joule", "Kilocalorie", "Wattora", "Kilowattora",
                "Elettronvolt", "Uk Thermal unit", "Us Thermal unit", "Piedi per libbre"};    

            /// <summary>
            /// Array containing the units of measurement of the thermometric scales
            /// </summary>
            public static readonly string[] SimbUnit =
             {"J", "kcal", "Wh", "kWh", "eV", "Btu", "Atu", "ft lbs" };

            /// <summary>
            /// Array containing the lower limits of the thermometric scales
            /// </summary>
            public static readonly double[] AbsValue =
                 { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };


            private double _value;
            private string _unitMeasure;
            private string _unitSymbol;

            #endregion

            #region Property  

            // Nome e simbolo della grandezza fisica
            public string MeasurementName { get => "Energy"; }
            public string MeasurementSymbol { get => "E"; }

            // valore scalare, Nome e Simbolo del misurazione da convertire
            public double Unit_Value  { get => _value;       private set => _value       = value; }
            public string Unit_Name   { get => _unitMeasure; private set => _unitMeasure = value; }
            public string Unit_Symbol { get => _unitSymbol;  private set => _unitSymbol  = value; }

            // Matrici contenenti rispettivamente, Nomi, Simboli e Valori limite delle unita' di misura

            public string[] UnitName     { get => NameUnit; }
            public string[] UnitSymbol   { get => SimbUnit; }
            public double[] UnitAbsValue { get => AbsValue; }

            #endregion
        }
    }
}