﻿using System;

/// <summary>
/// Library for the management of Measurement Physical Quantities
/// </summary>
namespace Physics
{
    /// <summary>
    /// Namespace that contains the physical quantities in the library
    /// </summary>
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Energy
        /// </summary>
        /// <seealso cref="Physics.PhysicalQuantities.IPhysical" />
        public partial class Energy : IPhysical
        {
            /// <summary>
            /// Generic Constructors
            /// Initializes a new instance whit value and symbol [0.0 K]
            /// </summary>
            public Energy()
            {
                _value = 0.0;
                _unitSymbol = "J";
            }

            /// <summary>
            /// Initializes a new instance of object whit symbol \"simb\" 
            /// and as its value the relative Absolute value
            /// </summary>
            /// <param name="simb">Thermometric Scale Symbol</param>
            public Energy(string simb)
            {
                _value = UnitAbsValue[Array.IndexOf(UnitSymbol, simb)];
                _unitSymbol = simb;
            }

            /// <summary>
            /// Initializes a new instance with value \"value\" 
            /// and with \"k\" (kelvin) as a Thermometric Scale
            /// </summary>
            /// <param name="value">Energy value</param>
            public Energy(double value)
            {
                if (value >= 0.0) // Maggiore dello Zero kelvin
                {
                    _value = value;
                }
                else
                {
                    _value = 0.0;
                }

                _unitSymbol = "J";
            }

            /// <summary>
            /// Initializes a new instance with value \"value\" and \"symb\" as a thermometric scale
            /// </summary>
            /// <param name="simb">Symbol of unity</param>
            /// <param name="valueTemp">Energy value</param>
            public Energy(string simb, double valueTemp)
            {
                if (ValidateValue(simb, valueTemp))
                {
                    _value = valueTemp;
                    _unitSymbol = simb;
                }
                else
                {
                    _value = 0.0;
                    _unitSymbol = "J";
                }
            }
        }
    }
}
