﻿using System;
/// <summary>
/// Library for the management of Measurement Physical Quantities
/// </summary>
namespace Physics
{
    /// <summary>
    /// Namespace that contains the physical quantities in the library
    /// </summary>
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Energy
        /// </summary>
        /// <seealso cref="Physics.PhysicalQuantities.IPhysical" />
        public partial class Energy : IPhysical
        {
            /// <summary>
            /// Verify that the symbol is a Symbol of the selected unit of measurement
            /// </summary>
            /// <param name="simb">Symbol of the unit of measurement to be verified</param>
            /// <returns>true if the symbol is valid, otherwise false</returns>
            public bool CheckUnitName(string simb)
            {
                if (Array.IndexOf(UnitSymbol, simb) == -1)
                    return false;
                return true;
            }

            /// <summary>
            /// Verify that the measurement value is in accordance with the unit
            /// </summary>
            /// <param name="Simb">Symbol of the unit of measurement</param>
            /// <param name="value">Value of the measure</param>
            /// <returns>true if the value is allowed, otherwise false</returns>
            public bool ValidateValue(string Simb, double value)
            {
                int index = Array.IndexOf(UnitSymbol, Simb);
                if (index <= -1)
                    return false;
                else
                {
                    if (UnitAbsValue[index] > value)
                        return false;
                    else
                        return true;
                }
            }
        }
    }
}