﻿
namespace Physics
{
    namespace PhysicalQuantities
    {
        /// <summary>
        /// \Interface IPhysical
        /// \brief Interface for physical quantities management
        /// </summary>
        public interface IPhysical
        {
            // Name and symbol of physical quantities            
           
            /// <summary>
            /// Gets the name of the measurement.
            /// </summary>
            /// <value>
            /// The name of the measurement.
            /// </value>
            /// 
            string MeasurementName      { get; } //!> Nome della grandezza fisica            
            
            /// <summary>
            /// Gets the measurement symbol.
            /// </summary>
            /// <value>
            /// The measurement symbol.
            /// </value>
            /// 
            string MeasurementSymbol    { get; } /*!> Simbolo della grandezza fisica  */

            // value, name and symbol of the measurement to be converted            
            /// <summary>
            /// Gets the unit value.
            /// </summary>
            /// <value>
            /// The unit value.
            /// </value>
            double Unit_Value  { get; }

            /// <summary>
            /// Gets the name of the unit.
            /// </summary>
            /// <value>
            /// The name of the unit.
            /// </value>
            string Unit_Name   { get; }

            /// <summary>
            /// Gets the unit symbol.
            /// </summary>
            /// <value>
            /// The unit symbol.
            /// </value>
            string Unit_Symbol { get; }

            //Arrays with the names and symbols of the different units of measurement +
            
            /// <summary>
            /// Gets the name of the unit.
            /// </summary>
            /// <value>
            /// The name of the unit.
            /// </value>
            string[] UnitName { get; }

            /// <summary>
            /// Gets the unit symbol.
            /// </summary>
            /// <value>
            /// The unit symbol.
            /// </value>
            string[] UnitSymbol { get; }

            /// <summary>
            /// Gets the unit abs value.
            /// </summary>
            /// <value>
            /// The unit abs value.
            /// </value>
            double[] UnitAbsValue { get; }

            /// <summary>
            /// Check that the \"simb\" is a symbol of the selected unit of measurement
            /// </summary>
            /// <param name="simb">Symbol of the unit of measurement to be verified</param>
            /// <returns>true if the \"simb\" is valid, otherwise false</returns>
            bool CheckUnitName(string simb);

            /// <summary>
            /// Verify that the measurement value is in accordance with the scale
            /// </summary>
            /// <param name="Simb">Symbol of the unit of measure</param>
            /// <param name="value">Value of the measure</param>
            /// <returns>true if the value is allowed, otherwise false </returns>
            bool ValidateValue(string Simb, double value);
       
            /// <summary>
            /// Convert the instance in to the \"Simb\" unit
            /// </summary>
            /// <returns>value in \"Simb\" units</returns>
            double ValueToUnit(string Simb);

            /// <summary>
            /// Convert the object to the reference unit
            /// </summary>
            /// <returns>value in reference unit</returns>
            double ValueFromUnit();

            /// <summary>
            /// Convert the instance in to the \"Simb\" unit
            /// </summary>
            /// <returns>New Instance in \"Simb\" units</returns>
            object ObjectToUnit(string Simb);
           
            /// <summary>
            /// Convert the object to the reference unit
            /// </summary>
            /// <returns>New Instance in reference units</returns>
            object ObjectFromUnit();

            /// <summary>
            /// Convert an object to the chosen unit
            /// </summary>
            /// <param name="SimbOut">Symbol of the Output unit</param>
            /// <returns></returns>
            object ObjectUnitToUnit(string SimbOut);

            /// <summary>
            /// Convert a value to the chosen unit
            /// </summary>
            /// <param name="SimbOut">Symbol of the output unit</param>
            /// <returns>value of the output unit</returns>
            double ValueUnitToUnit(string SimbOut);

            /// <summary>
            /// Redefines the object.
            /// </summary>
            /// <param name="symbol">Symbol of the new unit</param>
            /// <param name="value">value of the new unit</param>
            void RedefineObject(string symbol, double value);
            
            /// <summary>
            /// Ovveride of the method ToString()
            /// </summary>
            /// <returns>String referred to the instantiated object</returns>
            string ToString();  
        }
    }
}