﻿namespace Physics
{
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Pressure
        /// </summary>
        /// <seealso cref="Physics.PhysicalQuantities.IPhysical" />
        public partial class Pressure : IPhysical
        {
            #region Filed

            /// <summary>
            /// Array containing the names of the thermometric scales
            /// </summary>
            public static readonly string[] NameUnit =
             {"Pascal", "Bar", "Torr", "millimetri H2O", "Atmosfere", "Kilogrammi forza", "atmosfere tec", "barye" };

            /// <summary>
            /// Array containing the units of measurement of the thermometric scales
            /// </summary>
            public static readonly string[] SimbUnit =
            { "Pa", "bar", "torr", "mmH2O", "atm", "kgf", "ata", "Ba" };

            /// <summary>
            /// Array containing the lower limits of the thermometric scales
            /// </summary>
            public static readonly double[] AbsValue =
                {0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0} ;


            private double _value;
            private string _unitMeasure;
            private string _unitSymbol;

            #endregion

            #region Property  

            // Nome e simbolo della grandezza fisica            
            /// <summary>
            /// Gets the name of the measurement.
            /// </summary>
            /// <value>
            /// The name of the measurement.
            /// </value>
            public string MeasurementName { get => "Pressure"; }


            /// <summary>
            /// 
            /// </summary>
            public string MeasurementSymbol { get => "P"; }

            // valore scalare, Nome e Simbolo del misurazione da convertire            
            /// <summary>
            /// Gets the unit value.
            /// </summary>
            /// <value>
            /// The unit value.
            /// </value>
            public double Unit_Value { get => _value; private set => _value = value; }
            /// <summary>
            /// Gets the name of the unit.
            /// </summary>
            /// <value>
            /// The name of the unit.
            /// </value>
            public string Unit_Name { get => _unitMeasure; private set => _unitMeasure = value; }
            /// <summary>
            /// Gets the unit symbol.
            /// </summary>
            /// <value>
            /// The unit symbol.
            /// </value>
            public string Unit_Symbol { get => _unitSymbol; private set => _unitSymbol = value; }

            // Matrici contenenti rispettivamente, Nomi, Simboli e Valori limite delle unita' di misura            
            /// <summary>
            /// Gets the name of the unit.
            /// </summary>
            /// <value>
            /// The name of the unit.
            /// </value>
            public string[] UnitName { get => NameUnit; }
            /// <summary>
            /// Gets the unit symbol.
            /// </summary>
            /// <value>
            /// The unit symbol.
            /// </value>
            public string[] UnitSymbol { get => SimbUnit; }
            /// <summary>
            /// Gets the unit abs value.
            /// </summary>
            /// <value>
            /// The unit abs value.
            /// </value>
            public double[] UnitAbsValue { get => AbsValue; }

            #endregion
        }
    }
}