﻿using System;

namespace Physics
{
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Prova
        /// </summary>
        public partial class Prova : IPhysical
        {
            /// <summary>
            /// Initializes a new instance with value \"value\" 
            /// and \"symb\" as a thermometric scale
            /// </summary>
            /// <param name="simb">Symbol of unity</param>
            /// <param name="valueTemp">Prova value</param>
            public Prova(string simb, double valueTemp)
            {
                if (CheckUnitName(simb))
                {
                    if (ValidateValue(simb, valueTemp))
                    {
                        _value = valueTemp;
                        _unitSymbol = simb;
                    }
                    else
                    {
                    _unitSymbol = SimbUnit[0];
                    _value = UnitAbsValue[Array.IndexOf(UnitSymbol, simb)];
                    }
                }
                else
                {
                    _unitSymbol = SimbUnit[0];
                    _value = AbsUnit[0];
                }
            }

            /// <summary>
            /// Initializes a new instance whit value and symbol of base
            /// </summary>
            public Prova() : this(SimbUnit[0], AbsUnit[0])
            {
            }

            /// <summary>
            /// Initializes a new instance of object whit symbol \"simb\" 
            /// and as its value the relative Absolute value
            /// </summary>
            /// <param name="simb">Thermometric Scale Symbol</param>
            public Prova(string simb) : this(simb,1 )
            {
            }

            /// <summary>
            /// Initializes a new instance with value \"value\" 
            /// and with \"k\" (kelvin) as a Thermometric Scale
            /// </summary>
            /// <param name="value">Prova value</param>
            public Prova(double value) : this(SimbUnit[0], value)
            {
            }
        }
    }
}