﻿
namespace Physics
{
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the Prova
        /// </summary>
        /// <seealso cref="Physics.PhysicalQuantities.IPhysical" />
        public partial class Prova : IPhysical
        {
            /// <summary>
            /// Converts the value of kelvin to \"unitSimbol\"
            /// </summary>
            /// <returns>value in degrees \"unitSimbol\"</returns>
            public double ValueToUnit(string unitSimbol)
            {
                switch (unitSimbol)
                {//{1, 0.00001, 0.007500615, 0.1019744289, 0.0000098692, 0.101972, 0.000010197162129779, 10
                    //TODO: Verificare che l'oggetto sia kelvin e no altro
                    case "k":
                        return _value;
                    case "°C":
                        return _value * 0.00001;
                    case "°F":
                        return _value * 007500615;
                    case "°R":
                        return _value * 0.1019744289;
                    case "°De":
                        return _value * 0.000009892;
                    case "°N":
                        return _value * 0.101972;
                    case "°r":
                        return (_value*0.00010197162129779);
                    case "°Rø":
                        return _value *10;
                    default:
                        return _value;
                }
            }

            /// <summary>
            /// Converts the value of \"unitSimbol\" to Kelvin
            /// </summary>
            /// <returns>value of degree Kelvin</returns>
            public double ValueFromUnit()
            {
                switch (_unitSymbol)
                {
                    case "k":
                        return _value;
                    case "°C":
                        return _value / 0.00001;
                    case "°F":
                        return _value / 007500615;
                    case "°R":
                        return _value / 0.1019744289;
                    case "°De":
                        return _value / 0.000009892;
                    case "°N":
                        return _value / 0.101972;
                    case "°r":
                        return (_value / 0.00010197162129779);
                    case "°Rø":
                        return _value / 10;
                    default:
                        return _value;
                }
            }

            /// <summary>
            /// Converts the value of kelvin to \"unitSimbol\"
            /// </summary>
            /// <returns>New Instance in \"UnitSimbol\" degrees</returns>
            public object ObjectToUnit(string UnitSimbol)
            {
                return new Prova(UnitSimbol, ValueToUnit(UnitSimbol));
            }

            /// <summary>
            /// Converts the value of \"unitSimbol\" to Kelvin
            /// </summary>
            /// <returns>New Instance in kelvin degrees</returns>
            public object ObjectFromUnit()
            {
                return new Prova(ValueFromUnit());
            }

            /// <summary>
            /// Converts a Prova object to the chosen thermometric scale
            /// </summary>
            /// <param name="UnitSimbOut">Output thermometer scale symbol</param>
            /// <returns>New instance of Prova</returns>
            public object ObjectUnitToUnit(string UnitSimbOut)
            {
                // Prima Conversione
                // Converte il valore dell'oggetto in gradi Kelvin
                IPhysical Temporaneo = (IPhysical)ObjectFromUnit();

                return Temporaneo.ObjectToUnit(UnitSimbOut);
            }

            /// <summary>
            /// Values the unit to unit.
            /// </summary>
            /// <param name="UnitSimbOut">The unit simb out.</param>
            /// <returns></returns>
            public double ValueUnitToUnit(string UnitSimbOut)
            {
                // Creo una 2° instanza per evitare modicfiche alla 1°
                Prova temp = new Prova(ValueFromUnit());
                this.Unit_Value = temp.ValueToUnit(UnitSimbOut);
                this.Unit_Symbol = UnitSimbOut;

                return Unit_Value;
            }

            /// <summary>
            /// Redefines the object.
            /// </summary>
            /// <param name="symbol">Symbol of the new unit</param>
            /// <param name="value">value of the new unit</param>
            public void RedefineObject(string symbol, double value)
            {
                if (CheckUnitName(symbol) && ValidateValue(symbol, value))
                {
                    _value = value;
                    _unitSymbol = symbol;
                }
            }
        }
    }
}