﻿namespace Physics
{
    namespace PhysicalQuantities
    {
        /// <summary>
        /// Class that manages the temperature
        /// </summary>
        /// <seealso cref="Physics.PhysicalQuantities.IPhysical" />
        public partial class Temperature : IPhysical
        {
            #region Filed
            /// <summary>
            /// Array containing the names of the thermometric scales
            /// </summary>
            public static readonly string[] NameUnit =
             {"Kelvin","Celsius","Fahrenheit","Rankine",
			 "Delisle","Reamuer","Newton","Rømer" };

            /// <summary>
            /// Array containing the units of measurement of the thermometric scales
            /// </summary>
            public static readonly string[] SimbUnit =
             {"k","°C","°F","°R","°De","°r","°N","°Rø" };

            /// <summary>
            /// Array containing the lower limits of the thermometric scales
            /// </summary>
            public static readonly double[] AbsValue =
                {0.0, -273.15, -459.67, 0.0, 559.725, -218.52, -90.1395, -135.904};
            //    K,      C,       F,    R,    De,       r,       N,        Ro

            private double _value;
            private string _unitMeasure;
            private string _unitSymbol;
            #endregion

            #region Property    
            /// <summary>
            /// Gets the name of the measurement.
            /// </summary>
            /// <value>
            /// The name of the measurement.
            /// </value>
            public string MeasurementName { get => "Temperatura"; }
           
 		    /// <summary>
            /// Gets the measurement symbol.
            /// </summary>
            /// <value>
            /// The measurement symbol.
            /// </value>
            public string MeasurementSymbol { get => "T"; }

            /// <summary>
            /// 
            /// </summary>
            public double Unit_Value { get => _value; private set => _value = value; }
            
			/// <summary>
            /// Gets the name of the unit.
            /// </summary>
            /// <value>
            /// The name of the unit.
            /// </value>
            public string Unit_Name { get => _unitMeasure; private set => _unitMeasure = value; }
            
			/// <summary>
            /// Gets the unit symbol.
            /// </summary>
            /// <value>
            /// The unit symbol.
            /// </value>
            public string Unit_Symbol { get => _unitSymbol; private set => _unitSymbol = value; }

            /// <summary>
            /// Gets the name of the unit.
            /// </summary>
            /// <value>
            /// The name of the unit.
            /// </value>
            public string[] UnitName { get => NameUnit; }
            
			/// <summary>
            /// Gets the unit symbol.
            /// </summary>
            /// <value>
            /// The unit symbol.
            /// </value>
            public string[] UnitSymbol { get => SimbUnit; }
            
			/// <summary>
            /// Gets the unit abs value.
            /// </summary>
            /// <value>
            /// The unit abs value.
            /// </value>
            public double[] UnitAbsValue { get => AbsValue; }
            #endregion
        }
    }
}